==> kpl-2.2.tar.bz2: kpl-2.2/kpl/kplchecklistitem.cpp <==
/***************************************************************************
                          kplchecklistitem.cpp  -  description
                             -------------------

    This file is a part of kpl - a program for graphical presentation of
    data sets and functions.

    begin                : Sun Aug 22 1999
    copyright            : (C) 2001 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kiconloader.h>
#include "kplchecklistitem.h"

KplCheckListItem::KplCheckListItem(QListView* parent) :
  QListViewItem(parent), on(false)
{
  init();
}

KplCheckListItem::KplCheckListItem(KplCheckListItem* parent) :
  QListViewItem(parent), on(false)
{
  init();
}

KplCheckListItem::KplCheckListItem(QListView* parent, KplCheckListItem* after) :
  QListViewItem(parent, after), on(false)
{
  init();
}

KplCheckListItem::KplCheckListItem(KplCheckListItem* parent,
                                   KplCheckListItem* after) :
  QListViewItem(parent, after), on(false)
{
  init();
}

KplCheckListItem::~KplCheckListItem()
{
}

void KplCheckListItem::setOn(bool b)
{
  bool old = on;
  on = b;
  if (on != old) {
    init();
    emit stateChanged(this, on);
  }
}

bool KplCheckListItem::isOn() const
{
  return on;
}

void KplCheckListItem::activate()
{
  QPoint pos;
  if (!activatedPos(pos))
	  setOn(!on);
}

void KplCheckListItem::init()
{
  setPixmap(0, BarIcon(on ? "checked" : "unchecked"));
}

==> kpl-3.0.tar.bz2: kpl-3.0/kpl/kplchecklistitem.cpp <==
/***************************************************************************
                          kplchecklistitem.cpp  -  description
                             -------------------

    This file is a part of kpl - a program for graphical presentation of
    data sets and functions.

    begin                : Sun Aug 22 1999
    copyright            : (C) 2002 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kiconloader.h>
#include <kapp.h>
#include "kplchecklistitem.h"

KplCheckListItem::KplCheckListItem(KListView* _parent, KplCheckListItem* after) :
#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 1)
  KListViewItem(_parent, after), on(false)
#else
  QListViewItem(_parent, after), on(false)
#endif
{
  init();
}

KplCheckListItem::KplCheckListItem(KplCheckListItem* _parent,
                                   KplCheckListItem* after) :
#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 1)
  KListViewItem(_parent, after), on(false)
#else
  QListViewItem(_parent, after), on(false)
#endif
{
  init();
}

KplCheckListItem::~KplCheckListItem()
{
}

void KplCheckListItem::setOn(bool b)
{
  bool old = on;
  on = b;
  if (on != old) {
    init();
    emit stateChanged(this, on);
  }
}

bool KplCheckListItem::isOn() const
{
  return on;
}

void KplCheckListItem::init()
{
  setPixmap(0, BarIcon(on ? "checked" : "unchecked"));
}
